@@ -13,8 +13,8 @@
 #' \tabular{ll}{
 #' Package: \tab predictoR\cr
 #' Type: \tab Package\cr
-#' Version: \tab 2.0.7\cr
-#' Date: \tab 2022-04-27\cr
+#' Version: \tab 3.0.0\cr
+#' Date: \tab 2022-02-09\cr
 #' License: \tab GPL (>=2)\cr
 #' }
 #' @keywords package
@@ -23,4 +23,6 @@
 NULL
 utils::globalVariables(c(
   "datos","<<-", "z", "prop", "x",
-  "OOB", "cont", "MeanDecreaseAccuracy", "plot.MC", "y", "importancia", "count"))
\ No newline at end of file
+  "OOB", "cont", "MeanDecreaseAccuracy", 
+  "plot.MC", "y", "importancia", "count", 
+  "desc", "name", "value", "color", "var"))
\ No newline at end of file
